@@ -224,6 +224,22 @@ class EmaOperator(IndicatorOperator):
 
         return data
 
+class SmaOperator(IndicatorOperator):
+    @staticmethod
+    def get_column_names():
+        return ["Sma"]
+
+    def __init__(self, prefix, period):
+        self.prefix = prefix
+        self.period = period
+        self.logger = logging.getLogger(__name__)
+
+    def apply(self, data: IndicatorData) -> IndicatorData:
+        ema_col = self.calculate_final_column_name(prefix=self.prefix, col_name=self.get_column_names()[0], period=self.period)
+        data[ema_col] = SMA(data["Close"], timeperiod=self.period)
+
+        return data
+
 
 class AdxOperator(IndicatorOperator):
     @staticmethod
